<template>
  <span :id="id" :name="field.name+'_show'" class="kms-control">
    <template
      v-if="field.displayType == Constant.PermissionType_HIDDEN || (field.textType && field.textType.toLowerCase() == 'hidden')"
    >
      <!-- 隐藏 TODO:注意，隐藏时不应该有hidden的field存在，有安全问题，以后要改过来：Jarod -->
      <span>{{field.hiddenValue}}</span>
    </template>
    <template v-else-if="field.displayType == Constant.PermissionType_MODIFY">
      <!-- 可编辑 -->
      <div class="file-kms-wrap">
        <div class="titleName">
          {{field.discript?field.discript:field.name}}
          <span style="color:red" v-if="field.essential || field.instantValidate || (field.validateLibs && field.validateLibs.indexOf('checkEmpty_system') > 0)">*</span>
        </div>
        <div class="file-list" v-show="selectFileData.length > 0">
          <div class="list" v-for="(item, index) in selectFileData" :key="index">
            <div class="no-edit" @click="handlePreview(item)" v-if="!item.isEdit">
              <div class="list-left">
                <i class="el-icon-tickets"></i>
                {{item.fileName}}
              </div>
              <div class="list-right">
                <span class="icon-down" @click.stop="downloadFile(item)">
                  <van-icon name="down" />
                </span>
                <span class="icon-del" @click.stop="deleteFile(item,index)">
                  <van-icon name="delete-o" />
                </span>
                <span class="icon-edit" @click.stop="editFileName(item,index)">
                  <van-icon name="eye-o" />
                </span>
              </div>
            </div>
            <div class="edit" v-else>
              <div class="input">
                <el-input v-model="item.name"></el-input>
              </div>
              <div class="icon-input">
                <i class="el-icon-circle-check" @click="confirm(item, index)"></i>
                <i class="el-icon-circle-close" @click="cancel(index)"></i>
              </div>
            </div>
          </div>
        </div>
        <div class="kms-wrap">
          <div class="" @click="openKmDialog">
            <!-- {{field.name}} --dd -->
            <van-button 
              icon="add-o" 
              size="small" 
              plain 
              hairline 
              round 
              type="info">
              {{field.name}}
            </van-button>
          </div>
        </div>
      </div>
    </template>
    <template v-else-if="field.readOnlyShowValOnly">
      <!-- 只读（文本模式） -->
      <template>{{field.value}}</template>
    </template>
    <template v-else>
      <!-- 只读（控件模式） -->
      <div class="file-kms-wrap">
        <div class="titleName">
          {{field.discript?field.discript:field.name}}
          <span style="color:red" v-if="field.essential || field.instantValidate || (field.validateLibs && field.validateLibs.indexOf('checkEmpty_system') > 0)">*</span>
        </div>
      </div>
    </template>
    <van-popup 
      v-model="dialogVisible" 
      position="bottom" 
      :style="{ height: '80%', width:'100%'}" 
      get-container="body"
      class="kms-control-dialog"
    >
      <div class="kms-data-wrap">
        <div class="header">
          不可用
        </div>
        <div class="container">
          <div class="list" v-for="(column, index) in tableData" :key="index">
            <div class="list-left-wrap">
              <label class="mint-checklist-label view-li-leftLabel">
                <span class="mint-checkbox">
                  <input
                    type="checkbox"
                    class="mint-checkbox-input"
                    :value="column.id"
                    v-model="selectedDocIds"
                  />
                  <span class="mint-checkbox-core"></span>
                </span>
              </label>
              <span class="middle"></span>
            </div>
            <div class="list-right-wrap">
              <div class="name">
                {{column.fName}}:{{column.fileName}}
              </div>
              <div>
                {{column.cTime}}:{{column.createDate}}
              </div>
            </div>
          </div>
        </div>
        <div class="footer">
          <van-button 
            class="btn"
            style="width: 50%;" 
            size="small" 
            plain 
            hairline 
            round 
            type="danger"
            @click="onCancel"
            >
            取 消
          </van-button>
          <van-button 
            style="width: 50%;"
            size="small" 
            hairline 
            round 
            type="info"
            @click="onOk"
            >
            确 定
          </van-button>
        </div>
      </div>
    </van-popup>
    <!-- <el-dialog
      :title="field.name"
      :visible.sync="dialogVisible"
      width="50%"
    >
      <div class="km-dialog">
        <div class="header">
          <div class="left">
            <el-button v-if="selectData.length" type="success" size="small" @click="onOk">确定</el-button>
          </div>
          <div class="right">
            名称：
            <span class="sear-input">
              <el-input @keyup.enter.native="openKmDialog" v-model="searchValue" ></el-input>
            </span>
            <span class="sear-btn">
              <el-button size="small"  @click="openKmDialog">查询</el-button>
            </span>
          </div>
        </div>
        <div class="table-box">
        </div>

      </div>
    </el-dialog> -->
  </span>
</template>

<script>
import Constant from "@/Constant.js"
import controlHidden from "@/assets/js/controlHidden.js"
export default {
  name: "o-file-kms",
  props: ["id"],
  computed: {
    field: function() {
      let formData = this.$parent.findField(this.id);
      return formData;
    }
  },
  mounted(){
    this.$nextTick(()=>{
      let field = this.field;
      if(field.isHideType) {
        let id = this.id,
          formShowType = field.formShowType;
        controlHidden({id, field, formShowType})
      }
    })
  },
  data: function() {
    return { 
      dialogVisible:false,
      Constant,
      isActive:false,
      errorMessage:'',
      searchValue:'',
      tableData:[],
      selectData:[],
      selectFileData:[],
      showLogsDialog: false,
      showLogsIcon:true,
      operationData:'',
      selectedDocIds: [],
    };
  },
  methods: {
    confirm(item,index){
      let name = item.name;
      // name = name.replace(/^(\s|.)+|(\s|.)+$/g, "");
      this.selectFileData[index].fileName = name + "." + item.suffix;
      this.selectFileData[index].isEdit = false;
      this.$forceUpdate();
    },
		cancel(index) {
      this.selectFileData[index].isEdit = false;
      this.$forceUpdate();
    },
    editFileName(item, index){
      this.selectFileData[index].isEdit = true;
      this.$forceUpdate();
    },
    handlePreview(file) {
			this.$api.getenvironment(
				{
					onSucess: res => {
						if(res.data.errcode === 0) {
							if(res.data.data === true) {
                let realName = file.filePath.split("/")[file.filePath.split("/").length - 1];
                let kmsPath = "/uploads/kms/" + file.filePath;
                this.$api.getHasPdfFile(
                  kmsPath,
                  realName,
                  {
                    onSucess: resp => {
                      if(res.data.data === true) {
                        let isEdit = this.field.previewEdit?'edit':'';
                        let waterMark = this.field.watermark?encodeURI(this.field.watermark):undefined;
                        let openWaterMark = this.field.openWaterMark;
                        let curEditUserId = file.curEditUserId;
                        let userName = this.$store.state.myProfile.name;
                        let showTrackRevisions = this.field.showTrackRevisions;
                        let selectEditPlug = this.field.selectEditPlug;
                        let cp = obpmConfig.obpmFilePath;
												sessionStorage.setItem("obpmContextPath", cp);
												let statiContextPath = obpmConfig.statiContextPath;
												let pdfPath = "";
												if(statiContextPath) { //5.0 trunk
													pdfPath = obpmConfig.statiContextPath;
												}else { //4.4 stable
													pdfPath = cp;
												}
                        let url = pdfPath + '/portal/vue/pdf/pdfviewer.html?action=' + isEdit + 
                           "&path=/uploads/kms/" + file.filePath + 
                            "&name=" + realName + 
                            "&showName=" + file.fileName + 
                            "&waterMark=" + waterMark + 
                            "&openWaterMark=" + openWaterMark +
                            "&curEditUserId=" + curEditUserId  +
                            "&userName=" + userName + 
                            "&showTrackRevisions=" + showTrackRevisions +
                            "&selectEditPlug=" + selectEditPlug;
                        window.open(url);
                      }
                    }
                  }
                )
								
							}
						}
					}
				}
			)
		},

    hiddenLogsDialog() {
      this.showLogsIcon = false;
      this.showLogsDialog = false;
    },
    enter(){
      if(this.field.isModified) {
        this.showLogsIcon = true;
      }
    },
    getOperationLogs() {
      let obj = {};
      obj.fieldName = this.field.name;
      this.operationData = obj;
      this.showLogsDialog = true;
    },

    downloadFile(item){
      let name = item.fileName;
      let path = '/uploads/kms/' + item.filePath;
      this.$api.templateDownload(
        name,
        path,
        {
          onSucess: response => {
            console.log("res--->",response)
            let fileName = "";
            let type = response.headers['content-type'];
            if(response.headers['content-disposition']) {
              //fileName = decodeURIComponent(response.headers['content-disposition'].split("=")[1]);
              fileName = name;
            }else {
              fileName="下载";
            }
            this.download(response, type, fileName);
          }
        }
      )
    },

    download(res, type, filename){
      const blob = new Blob([res.data], {
        // 如果后端没返回下载文件类型，则需要手动设置：type: 'application/pdf;chartset=UTF-8' 表示下载文档为pdf，如果是word则设置为msword，excel为excel
        type: type
      });
      const a = document.createElement('a');
      const herf = window.URL.createObjectURL(blob);
      // 下载链接
      a.href = herf;
      // 下载文件名,如果后端没有返回，可以自己写a.download = '文件.pdf'
      a.download = filename;
      document.body.appendChild(a);
      a.click();
      document.body.removeChild(a);
      window.URL.revokeObjectURL(herf);
    },

    deleteFile(item,index){
      let field = this.field;
      this.$confirm('此操作将永久删除该文件, 是否继续?', '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning'
      }).then(() => {
        this.$api.deleteKmsFile(
          this.$root.appid, 
          field.formId, 
          field.docId, 
          item.filePath,
          {
            onSucess: res=> {
              if(res.data.errcode == 0) {
                this.selectFileData.splice(index,1);
                this.$notify({
                  title: '',
                  message: res.data.data,
                  type: 'success'
                });
              }
            }
          }
        )
      }).catch(() => {
                
      });
    },

    onOk() {
      let td = this.tableData;
      let sd = this.selectedDocIds;
      let arr = [];
      if(sd.length > 0) {
        for (let i = 0; i < sd.length; i++) {
          for(let j = 0; j < td.length; j++) {
            if(sd[i] == td[j].id) {
              arr.push(td[j])
            }
          }
        }
        this.selectData = arr;
      }else {
        this.selectData = [];
      }

      let list = JSON.parse(JSON.stringify(this.selectData));
      list.forEach(el => {
        let a1 = el.fileName.split(".");
        el.isEdit = false;
        el.suffix = a1[a1.length - 1];
        a1.length = a1.length - 1;
        if(a1.length>1){
          el.name = a1.join(".");
        }else {
          el.name = a1[0];
        }
      });
      this.selectFileData = list;
      this.dialogVisible = false; 
    },

    onCancel() {
      this.dialogVisible = false;
    },
    
    openKmDialog() {
      this.dialogVisible = true;
      //fileName=&orderByfield=CREATE_DATE&orderMode=desc&pageNo=1&linesPerPage=10&_=1594349604925
      let params = {
            fileName:this.searchValue,
            orderByfield:'CREATE_DATE',
            orderMode:'desc',
            pageNo:1,
            linesPerPage:10,
            _: new Date().getTime(),
          }
      this.$api.getKmsFiles(
        params,
        {
          onSucess: res => {
            let newData = res.data.data.datas.map(item => {
              return {
                fileName: item.name,
                createDate: item.createDate,
                filePath: item.url,
                curEditUserId: item.creatorId,
                id: item.id,
                fName: '名称',
                cTime: '创建时间'
              }
            });
            this.tableData = newData;
          }
        }
      )
    },
    onChange(){
      if (this.field.refreshOnChanged){
        this.$parent.refresh(this.id);
      }
    }
  },
};
</script>
